==> jboss-eap-7.4.2-core-src.zip: jboss-eap-7.4-core-src/process-controller/src/main/java/org/jboss/as/process/ProcessInfo.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.process;

/**
 * @author <a href="mailto:david.lloyd@redhat.com">David M. Lloyd</a>
 */
public final class ProcessInfo {
    private final String processName;
    private final String authKey;
    private final boolean running;
    private final boolean stopping;

    ProcessInfo(final String processName, final String authKey, final boolean running, final boolean stopping) {
        this.processName = processName;
        this.authKey = authKey;
        this.running = running;
        this.stopping = stopping;
    }

    public String getProcessName() {
        return processName;
    }

    public String getAuthKey() {
        return authKey;
    }

    public boolean isRunning() {
        return running;
    }

    public boolean isStopping() {
        return stopping;
    }
}

==> jboss-eap-8.0.0-core-src.zip: jboss-eap-8.0-core-src/process-controller/src/main/java/org/jboss/as/process/ProcessInfo.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.process;

/**
 * @author <a href="mailto:david.lloyd@redhat.com">David M. Lloyd</a>
 */
public final class ProcessInfo {
    private final String processName;
    private final String pcAuthKey;
    private final boolean running;
    private final boolean stopping;

    ProcessInfo(final String processName, final String pcAuthKey, final boolean running, final boolean stopping) {
        this.processName = processName;
        this.pcAuthKey = pcAuthKey;
        this.running = running;
        this.stopping = stopping;
    }

    public String getProcessName() {
        return processName;
    }

    public String getPCAuthKey() {
        return pcAuthKey;
    }

    public boolean isRunning() {
        return running;
    }

    public boolean isStopping() {
        return stopping;
    }
}
